@@ -74,6 +74,9 @@ class Need(object):
     """
     error = Exception
 
+    def __init__(self, bool_=True):
+        self.bool_ = bool_
+
     def __call__(self, f):
         @wraps(f)
         def decorated(*args, **kargs):
@@ -106,11 +109,11 @@ class Need(object):
             Returns:
                 (bool) - True if the need is met, False otherwise.
         """
-        return True
+        return self.bool_
 
     # Aliases for is_met().
     def __bool__(self):
-        return self.is_met()
+        return bool(self.is_met())
     __nonzero__ = __bool__
 
 class NegativeNeed(Need):
@@ -146,8 +149,6 @@ def needs(need):
 
         needs(login_need)(f) == login_need(f)
     """
-    def adapt(f):
-        return need(f)
-    return adapt
+    return need
 
 no_need = Need()
